%define	major	3
%define	api	1
%define	libname %mklibname dbus- %{api} %{major}
%define	devname %mklibname -d dbus- %{api}

%define enable_test 0
%define enable_verbose 0

%define git_url git://git.freedesktop.org/git/dbus/dbus

%bcond_without	uclibc

Summary:	D-Bus message bus
Name:		dbus
Version:	1.6.8
Release:	2
License:	GPLv2+ or AFL
Group:		System/Servers
URL:		http://www.freedesktop.org/Software/dbus
Source0:	http://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.gz
Source1:	doxygen_to_devhelp.xsl
# (fc) 1.0.2-5mdv disable fatal warnings on check (fd.o bug #13270)
Patch3:		dbus-1.0.2-disable_fatal_warning_on_check.patch
# (bor) synchronize dbus.service with dbus.target so dependencies work
Patch7:		dbus-1.6.2-dbus.service-before-dbus.target.patch

BuildRequires:	docbook-dtd412-xml
BuildRequires:	doxygen
BuildRequires:	libtool
BuildRequires:	xmlto
BuildRequires:	expat-devel >= 2.0.1
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(libcap-ng)
BuildRequires:	pkgconfig(sm)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(libsystemd-daemon) >= 32
BuildRequires:	pkgconfig(libsystemd-login) >= 32
BuildRequires:	pkgconfig(systemd)
%if %{with uclibc}
BuildRequires:	uClibc-devel >= 0.9.33.2-9
%endif

Requires(post):	systemd-units
Requires(post):	systemd-sysvinit
Requires(preun):	systemd-units
Requires(postun):	systemd-units
Requires(pre):	rpm-helper
Requires(preun):	rpm-helper
Requires(post):	rpm-helper
Requires(postun):	rpm-helper
Requires(post):	chkconfig >= 1.3.37-3
Provides:	should-restart = system

%description
D-Bus is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package -n	uclibc-%{name}
Summary:	D-Bus message bus (uClibc linked)
Group:		System/Servers
Requires:	%{name} = %{EVRD}

%description -n	uclibc-%{name}
D-Bus is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package -n %{libname}
Summary:	Shared library for using D-Bus
Group:		System/Libraries

%description -n	%{libname}
D-Bus shared library.

%package -n	uclibc-%{libname}
Summary:	Shared library for using D-Bus (uClibc linked)
Group:		System/Libraries

%description -n	uclibc-%{libname}
D-Bus shared library.

%package -n %{devname}
Summary:	Libraries and headers for D-Bus
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
%if %{with uclibc}
Requires:	uclibc-%{libname} = %{version}-%{release}
%endif
Provides:	%{name}-devel = %{version}-%{release}
Conflicts:	%{_lib}dbus-1_0-devel < 1.4.14
Obsoletes:	%{_lib}dbus-1_3-devel < 1.4.14

%description -n	%{devname}
Headers and static libraries for D-Bus.

%package x11
Summary:	X11-requiring add-ons for D-Bus
Group:		System/Servers
Requires:	dbus = %{version}-%{release}

%description x11
D-Bus contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%package doc
Summary:	Developer documentation for D-BUS
Group:		Books/Computer books
Suggests:	devhelp
Conflicts:	%{devname} < 1.2.20

%description doc
This package contains developer documentation for D-Bus along with
other supporting documentation such as the introspect dtd file.

%prep
%setup -q
#only disable in cooker to detect buggy programs
#patch3 -p1 -b .disable_fatal_warning_on_check
%patch7 -p1 -b .after_dbus_target

%build
#needed for correct localstatedir location
%define _localstatedir %{_var}

COMMON_ARGS="--enable-systemd --with-systemdsystemunitdir=/lib/systemd/system \
    --enable-libaudit --disable-selinux --with-system-pid-file=%{_var}/run/messagebus.pid \
    --with-system-socket=%{_var}/run/dbus/system_bus_socket --with-session-socket-dir=/tmp \
    --libexecdir=/%{_lib}/dbus-%{api}"

export CONFIGURE_TOP=$PWD
%if %{with uclibc}
mkdir -p uclibc
pushd uclibc
%configure2_5x \
	CC=%{uclibc_cc} \
	CFLAGS="%{uclibc_cflags}" \
	$COMMON_ARGS \
	--with-sysroot=%{uclibc_root} \
	--bindir=%{uclibc_root}%{_bindir} \
	--disable-libaudit \
	--disable-static \
	--disable-tests \
	--disable-asserts \
	--disable-doxygen-docs \
	--disable-xml-docs \
	--enable-userdb-cache \
%if %enable_verbose
	--enable-verbose-mode
%else
	--disable-verbose-mode
%endif
# ugly hack to get rid of library search dir passed..
for i in `find -name Makefile`; do
	sed -e 's#-L%{_libdir}##g' -i $i
done
%make
popd
%endif

%serverbuild_hardened

#### Build once with tests to make check
%if %{enable_test}
# (tpg) enable verbose mode by default --enable-verbose-mode
mkdir -p test
pushd test
%configure2_5x \
	$COMMON_ARGS \
	--enable-libaudit \
	--disable-static \
	--enable-verbose-mode \
	--enable-tests=yes \
	--enable-verbose-mode=yes \
	--enable-asserts=yes \
	--disable-doxygen-docs \
	--disable-xml-docs

DBUS_VERBOSE=1 %make

make check
popd
%endif

mkdir -p shared
pushd shared
%configure2_5x \
	$COMMON_ARGS \
	--enable-libaudit \
	--disable-static \
	--disable-tests \
	--disable-asserts \
	--enable-doxygen-docs \
	--enable-xml-docs \
	--enable-userdb-cache \
%if %enable_verbose
	--enable-verbose-mode
%else
	--disable-verbose-mode
%endif

%make
doxygen Doxyfile

xsltproc -o dbus.devhelp %{SOURCE1} doc/api/xml/index.xml
popd

%check
make -C shared check

%install
%if %{with uclibc}
%makeinstall_std -C uclibc
install -d %{buildroot}%{uclibc_root}{/%{_lib},%{_libdir}}
mv %{buildroot}%{_libdir}/libdbus-%{api}.so.%{major}* %{buildroot}%{uclibc_root}/%{_lib}
ln -srf %{buildroot}%{uclibc_root}/%{_lib}/libdbus-%{api}.so.%{major}.* %{buildroot}%{uclibc_root}%{_libdir}/libdbus-%{api}.so

rm -f %{buildroot}%{uclibc_root}%{_bindir}/dbus-{launch,monitor}
%endif

%makeinstall_std -C shared

# move lib to /, because it might be needed by hotplug script, before
# /usr is mounted
mkdir -p %{buildroot}/%{_lib} %{buildroot}%{_var}/lib/dbus

mv %{buildroot}%{_libdir}/*dbus-1*.so.* %{buildroot}/%{_lib} 
ln -sf ../../%{_lib}/libdbus-%{api}.so.%{major} %{buildroot}%{_libdir}/libdbus-%{api}.so

mkdir -p %{buildroot}%{_sysconfdir}/X11/xinit.d
cat << EOF > %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus
# to be sourced
if [ -z "\$DBUS_SESSION_BUS_ADDRESS" ]; then
  eval \`/usr/bin/dbus-launch --exit-with-session --sh-syntax\`
fi
EOF

chmod 755 %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus

# create directory
mkdir %{buildroot}%{_datadir}/dbus-%{api}/interfaces

# Make sure that when somebody asks for D-Bus under the name of the
# old SysV script, that he ends up with the standard dbus.service name
# now.
ln -s dbus.service %{buildroot}/lib/systemd/system/messagebus.service

#add devhelp compatible helps
mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus
mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus/api

cp shared/dbus.devhelp %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-specification.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-faq.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-tutorial.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp shared/doc/api/html/* %{buildroot}%{_datadir}/devhelp/books/dbus/api

# (tpg) remove old initscript
rm -rf %{buildroot}%{_sysconfdir}/rc.d/init.d/*

%pre
%_pre_useradd messagebus / /sbin/nologin
%_pre_groupadd daemon messagebus

%post
if [ "$1" = "1" ]; then
    /usr/bin/dbus-uuidgen --ensure
    /bin/systemctl enable dbus.service >/dev/null 2>&1 || :

%_post_service %{name} %{name}.service
fi

%postun
%_postun_userdel messagebus
%_postun_groupdel daemon messagebus

%preun
if [ "$1" = "0" ]; then
%_preun_service %{name}
fi

%triggerun -- dbus < 1.4.16-1
/bin/systemctl enable dbus.service >/dev/null 2>&1
/sbin/chkconfig --del messagebus >/dev/null 2>&1 || :
/bin/systemctl try-restart dbus.service >/dev/null 2>&1 || :

%triggerpostun -- dbus < 1.2.4.4permissive-2mdv
/sbin/chkconfig --level 7 messagebus reset

%files
%doc COPYING NEWS
%dir %{_sysconfdir}/dbus-%{api}
%config(noreplace) %{_sysconfdir}/dbus-%{api}/*.conf
%dir %{_sysconfdir}/dbus-%{api}/system.d
%dir %{_sysconfdir}/dbus-%{api}/session.d
%dir %{_var}/run/dbus
%dir %{_var}/lib/dbus
%dir %{_libdir}/dbus-1.0
%{_bindir}/dbus-daemon
%{_bindir}/dbus-send
%{_bindir}/dbus-cleanup-sockets
%{_bindir}/dbus-uuidgen
%{_mandir}/man*/*
%dir %{_datadir}/dbus-%{api}
%{_datadir}/dbus-%{api}/system-services
%{_datadir}/dbus-%{api}/services
%{_datadir}/dbus-%{api}/interfaces
# See doc/system-activation.txt in source tarball for the rationale
# behind these permissions
%dir /%{_lib}/dbus-%{api}
%attr(4750,root,messagebus) /%{_lib}/dbus-%{api}/dbus-daemon-launch-helper
/lib/systemd/system/dbus.service
/lib/systemd/system/messagebus.service
/lib/systemd/system/dbus.socket
/lib/systemd/system/dbus.target.wants/dbus.socket
/lib/systemd/system/multi-user.target.wants/dbus.service
/lib/systemd/system/sockets.target.wants/dbus.socket

%if %{with uclibc}
%files -n uclibc-%{name}
%{uclibc_root}%{_bindir}/dbus-daemon
%{uclibc_root}%{_bindir}/dbus-send
%{uclibc_root}%{_bindir}/dbus-cleanup-sockets
%{uclibc_root}%{_bindir}/dbus-uuidgen
%endif

%files -n %{libname}
/%{_lib}/*dbus-%{api}*.so.%{major}*

%if %{with uclibc}
%files -n uclibc-%{libname}
%{uclibc_root}/%{_lib}/libdbus-%{api}.so.%{major}*
%endif

%files -n %devname
%doc ChangeLog
%{_libdir}/libdbus-%{api}.so
%if %{with uclibc}
%{uclibc_root}%{_libdir}/libdbus-%{api}.so
%endif
%{_libdir}/dbus-1.0/include/
%{_libdir}/pkgconfig/dbus-%{api}.pc
%{_includedir}/dbus-1.0/

%files x11
%{_sysconfdir}/X11/xinit.d/*
%{_bindir}/dbus-launch
%{_bindir}/dbus-monitor

%files doc
%doc doc/introspect.dtd doc/introspect.xsl doc/system-activation.txt
%doc %{_datadir}/devhelp/books/dbus


%changelog
* Sat Oct 06 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6.8-2
+ Revision: 818526
- tune up scriplets
- do not restart dbus on upgrade, it causes network drop and x11 restart too

* Sat Sep 29 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.6.8-1
+ Revision: 817969
- version update 1.6.8

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - do uClibc build

* Sun Sep 09 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6.4-2
+ Revision: 816591
- drop old initscript, also remove patch 0

* Thu Jul 19 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6.4-1
+ Revision: 810309
- fix COMMON_ARGS
- update to new version 1.6.4
- disable build static libraries
- spec file clean

* Sat Jun 30 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6.2-2
+ Revision: 807611
- use pkgconfig stule buildrequires for systemd
- pass --enable-systemd option to configure script

* Thu Jun 28 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.6.2-1
+ Revision: 807380
- version update 1.6.2 it is new stable version

* Tue Apr 24 2012 Matthew Dawkins <mattydaw@mandriva.org> 1.4.20-1
+ Revision: 793180
- new version 1.4.20
- cleaned up spec

* Sat Mar 24 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.4.18-2
+ Revision: 786528
- do some cleaning
- drop ancient postun trigger

* Tue Mar 13 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.18-1
+ Revision: 784870
- update to new version 1.4.18

* Mon Dec 05 2011 Zé <ze@mandriva.org> 1.4.16-3
+ Revision: 737936
- systemd its already used by default
- use simple naming
-dynamic libs are required by default, need to have an explicite require
- docs should be installed independently

* Sat Nov 26 2011 Matthew Dawkins <mattydaw@mandriva.org> 1.4.16-2
+ Revision: 733482
- fixed errors introduced into spec
- added  bracket for systemd file
- rebuild
- clean up spec
- removed defattr
- removed clean section
- removed old ldconfig scriptlets
- removed mkrel & BuildRoot
- converted some BRs to pkgconfig provides
- removed dup devel provides
- removed dep loop creating requires for main pkg

* Tue Oct 11 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.16-1
+ Revision: 704409
- update to new version 1.4.16
- update scriplets for systemd support

* Sat Sep 03 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.14-1
+ Revision: 698129
- spec file clean
- update to new version 1.4.14
- drop patch 6, fixed by upstream

* Tue May 03 2011 Oden Eriksson <oeriksson@mandriva.com> 1.4.6-2
+ Revision: 663756
- mass rebuild

* Sat Apr 02 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.6-1
+ Revision: 649822
- update to new version 1.4.6

* Sun Mar 06 2011 Andrey Borzenkov <arvidjaar@mandriva.org> 1.4.4-3
+ Revision: 642298
- P7: synchronize dbus.service and dbus.target

* Sun Feb 27 2011 Funda Wang <fwang@mandriva.org> 1.4.4-2
+ Revision: 640209
- rebuild to obsolete old packages

* Fri Feb 18 2011 Götz Waschk <waschk@mandriva.org> 1.4.4-1
+ Revision: 638442
- update build deps
- new version

* Tue Jan 18 2011 Eugeni Dodonov <eugeni@mandriva.com> 1.4.1-2
+ Revision: 631460
- Ensure dbus is started correctly under systemd.
- Do not start/stop dbus via initscript when already done by systemd.
- Add systemd support.

  + Paulo Ricardo Zanoni <pzanoni@mandriva.com>
    - Backslash dollar sign on xinit.d script
      So we don't end with this:
        if [ -z "" ]; then

* Tue Dec 21 2010 Götz Waschk <waschk@mandriva.org> 1.4.1-1mdv2011.0
+ Revision: 623627
- update to new version 1.4.1

* Tue Sep 14 2010 Götz Waschk <waschk@mandriva.org> 1.4.0-1mdv2011.0
+ Revision: 578250
- update to new version 1.4.0

* Wed Mar 24 2010 Frederic Crozat <fcrozat@mandriva.com> 1.2.24-1mdv2010.1
+ Revision: 527107
- Release 1.2.24

* Wed Mar 17 2010 Frederic Crozat <fcrozat@mandriva.com> 1.2.22-1mdv2010.1
+ Revision: 524365
- Release 1.2.22
- Remove patches 7, 8 (merged upstream)

* Mon Mar 15 2010 Frederic Crozat <fcrozat@mandriva.com> 1.2.20-4mdv2010.1
+ Revision: 519138
- Patch7 (GIT): fix watch handling with threaded applications (Michael Meeks)
- Patch8 (GIT): fix build with libcap-ng enabled but selinux disabled
- build with libcap-ng enabled

* Sun Feb 07 2010 Funda Wang <fwang@mandriva.org> 1.2.20-3mdv2010.1
+ Revision: 501593
- currently youri-upload does not support uploading mixed arch packages
  at once. so dbus-doc should remain arch-dependent.

* Sat Feb 06 2010 Götz Waschk <waschk@mandriva.org> 1.2.20-2mdv2010.1
+ Revision: 501419
- rebuild for lost binary packages

* Fri Feb 05 2010 Funda Wang <fwang@mandriva.org> 1.2.20-1mdv2010.1
+ Revision: 501080
- fix group

  + Frederic Crozat <fcrozat@mandriva.com>
    - Release 1.2.20
    - Remove patches 11 & 12 (merged upstream)
    - Move documentation to seperate subpackage (Mdv bug #55360)

* Mon Oct 05 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.16-2mdv2010.0
+ Revision: 454014
- Patch16 (GIT): fix timeout handling

* Mon Jul 27 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.16-1mdv2010.0
+ Revision: 400625
- Release 1.2.16

* Tue May 12 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.4.6permissive-1mdv2010.0
+ Revision: 374914
- Release 1.2.4.6permissive
- Fix git_url

* Thu Feb 05 2009 Frederic Crozat <fcrozat@mandriva.com> 1.2.4.4permissive-2mdv2009.1
+ Revision: 337873
- Add support for runlevel 7

* Thu Jan 15 2009 Götz Waschk <waschk@mandriva.org> 1.2.4.4permissive-1mdv2009.1
+ Revision: 330046
- update to new version 1.2.4.4permissive

* Wed Oct 15 2008 Götz Waschk <waschk@mandriva.org> 1.2.4-1mdv2009.1
+ Revision: 293963
- update to new version 1.2.4

* Tue Aug 19 2008 Olivier Blin <blino@mandriva.org> 1.2.3-2mdv2009.0
+ Revision: 273673
- depend on network-auth service instead of network-up (not to slow down boot when auth does not require network)

* Thu Aug 07 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.3-1mdv2009.0
+ Revision: 265858
- Release 1.2.3
- Remove patches 7, 8, 9, 10, 12, 13 (merged upstream)

* Fri Jul 18 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.1-4mdv2009.0
+ Revision: 238250
- Patch7 (GIT): really enable userdb cache (fd.o bug #15588)
- Patch8 (GIT): cleanup guid-less connections correctly (fd.o bug #15571)
- Patch9 (GIT): Hold a reference during read/write dispatch (fd.o bug #15635)
- Patch10 (GIT): Reset initialized state on dbus_shutdown (fd.o bug #15570)
- Patch11 (GIT): increase default method timeout (Fedora)
- Patch12 (GIT): fix crash on timers leak (fd.o #15684)
- Patch13 (GIT): add API to change session bus environment variables (fd.o bug #16669)
- Update session launcher script to not start session bus if session bus variable is already set (Fedora)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri May 09 2008 Götz Waschk <waschk@mandriva.org> 1.2.1-3mdv2009.0
+ Revision: 205044
- call dbus-uuidgen in post to work around bug #40700

* Wed May 07 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.1-2mdv2009.0
+ Revision: 202805
- Fix level for initscript when not using parallel init

* Wed Apr 16 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.1-1mdv2009.0
+ Revision: 194692
- Release 1.2.1
- Remove patch7 (merged upstream)

* Fri Mar 28 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-5mdv2008.1
+ Revision: 190832
- Clean up devel package to not package 47MB of unused documentation

* Thu Mar 27 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-4mdv2008.1
+ Revision: 190617
- Patch7 : fix inotify monitoring, being too agressive
- Add easy way to enable verbose mode in specfile

* Tue Mar 25 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-3mdv2008.1
+ Revision: 189973
- Update patch0 to add soft dependency on network service at startup

* Tue Mar 04 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-2mdv2008.1
+ Revision: 178271
- should-restart is a provides, not a suggests

* Wed Feb 27 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-1mdv2008.1
+ Revision: 175910
- Release 1.1.20
- Remove patch7, merged upstream
- no longer restart system bus, rely on should-start = system
- not use rpm-helper for adding service to prevent restarting system bus

* Wed Feb 20 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-3mdv2008.1
+ Revision: 173247
-Own some directories (might fix Mdv bug #37567)

  + Thierry Vignaud <tv@mandriva.org>
    - fix spacing at top of description

* Wed Feb 06 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-2mdv2008.1
+ Revision: 163029
- Patch7 (Fedora): fix dbus not always exiting after X shutdown

* Fri Jan 18 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-1mdv2008.1
+ Revision: 154583
- Release 1.1.4
- remove patch7, merged upstream

* Thu Jan 17 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.3-2mdv2008.1
+ Revision: 154280
-Patch 7 (Timo Hoenig): fix inotify backend to not DoS system on upgrade

* Wed Jan 16 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.3-1mdv2008.1
+ Revision: 153648
- Release 1.1.3
- Remove patches 1, 2, 4, 5 (merged upstream)
- Regenerate patch0 (partially merged)

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-4mdv2008.1
+ Revision: 120079
- Disable checks (don't pass on x86-64)
- Clean specfile
- Remove unapproved patch

  + Paulo Andrade <pcpa@mandriva.com.br>
    - This is a "noop" patch. But it can be considered a list of the functions,
      code from X Server uses from dbus (libdbus-1), at a later stage, this library
      can be changed to make available only the public symbols.

* Fri Nov 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-3mdv2008.1
+ Revision: 109158
- Disable patch3 (disable fatal warnings on check) for cooker, to detect buggy usage of DBus

* Mon Oct 15 2007 Götz Waschk <waschk@mandriva.org> 1.1.2-2mdv2008.1
+ Revision: 98605
- new devel name

* Mon Oct 15 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-1mdv2008.1
+ Revision: 98570
- Remove patch4, merged upstream
- Patch4 (Fedora): fix arborting (fd.o bug #12430)
- Patch5 (git): fix PIE usage
- Patch6 (Fedora): generate xml doc
- Package devel help in devhelp format

* Tue Sep 11 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-10mdv2008.0
+ Revision: 84492
- Add requires(post) on lib package in main package (Mdv bug #31876)

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%{_datadir}/man by %%{_mandir}!

* Thu Aug 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-9mdv2008.0
+ Revision: 64326
- Patch4 (CVS): various bug fixes

* Thu Jul 12 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-8mdv2008.0
+ Revision: 51613
- enable dbus for runlevel 2

* Wed Jul 11 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-7mdv2008.0
+ Revision: 51319
- Enforce dependency of lib package on main package, just in case a program
  is linked to libdbus but doesn't requires dbus package

* Thu Jun 07 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.2-6mdv2008.0
+ Revision: 36905
- rebuild for expat


* Tue Mar 20 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-5mdv2007.1
+ Revision: 147000
- Patch3 (Debian): disable fatal warnings on check by default

* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.0.2-4mdv2007.1
+ Revision: 146591
- bump release
- no need to package big ChangeLog when NEWS is already there

* Tue Jan 23 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-3mdv2007.1
+ Revision: 112518
- Disable assertion and tests for packaged binaries. Build assertions and tests at compile time
  to check if everything is ok

* Wed Dec 13 2006 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-2mdv2007.1
+ Revision: 96425
- Release 1.0.2
  Remove patch3 (merged upstream)

* Thu Nov 23 2006 Frederic Crozat <fcrozat@mandriva.com> 1.0.1-2mdv2007.1
+ Revision: 86697
- Force rebuild
- Rebuild
- Release 1.0.1
- Patch1: add inotify support
- Patch2: fix config file creation notification with dnotify
- Patch3 (CVS): fix assertion

* Fri Nov 10 2006 Götz Waschk <waschk@mandriva.org> 1.0.0-1mdv2007.0
+ Revision: 80522
- new version

* Sat Nov 04 2006 Götz Waschk <waschk@mandriva.org> 0.95-1mdv2007.1
+ Revision: 76480
- new version
- drop patch 1
- drop uuidgen workaround
- create /var/lib/dbus directory

* Sun Oct 29 2006 Götz Waschk <waschk@mandriva.org> 0.94-9mdv2007.1
+ Revision: 73643
- rebuild
- add fix for upstream bug 8780

* Wed Oct 25 2006 Götz Waschk <waschk@mandriva.org> 0.94-7mdv2007.0
+ Revision: 72405
- bot rebuild
- fix permissions of the machine-id file
- call dbus-uuidgen in postinstallation (bug #26723)

* Wed Oct 18 2006 Götz Waschk <waschk@mandriva.org> 0.94-4mdv2007.0
+ Revision: 65799
- rename system socket (gnome bug #362601)

* Tue Oct 17 2006 Götz Waschk <waschk@mandriva.org> 0.94-3mdv2006.0
+ Revision: 65533
- fix buildrequires
- fix buildrequires
  update file list
- Import dbus

* Tue Oct 17 2006 Gtz Waschk <waschk@mandriva.org> 0.94-1mdv2007.1
- update file list
- drop patches 1,2
- New version 0.94

* Fri Sep 01 2006 Gtz Waschk <waschk@mandriva.org> 0.92-6mdv2007.0
- fix buildrequires

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-5mdv2007.0
- Enable asserts and verbose mode, since dbus isn't 1.0 yet (J5)

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-4mdv2007.0
- Patch1 (CVS): fix vtable crash
- Patch2: trap SIGTERM to be able to kill session bus (Mdv bug #22143)

* Fri Aug 25 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.92-3
- fix xinit.d script to use sh-syntax, since it is always sourced by /bin/sh

* Fri Aug 25 2006 Olivier Blin <blino@mandriva.com> 0.92-2mdv2007.0
- prefix the xinit.d script with a 2 digit number
- the xinit.d script is not a config file

* Tue Aug 22 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-1mdv2007.0
- Release 0.92
- remove patch1 (merged upstream)

* Fri Aug 18 2006 Frederic Crozat <fcrozat@mandriva.com> 0.91-5mdv2007.0
- Patch1 (CVS): fix threads deadlock

* Thu Aug 10 2006 Gtz Waschk <waschk@mandriva.org> 0.91-4mdv2007.0
- fix the patch again

* Thu Aug 10 2006 Gtz Waschk <waschk@mandriva.org> 0.91-3mdv2007.0
- update patch with a fix for bug #21935

* Tue Aug 08 2006 Gtz Waschk <waschk@mandriva.org> 0.91-2mdv2007.0
- fix buildrequires

* Wed Jul 19 2006 Frederic Crozat <fcrozat@mandriva.com> 0.90-1mdv2007.0
- Release 0.90
- Remove bindings (packaged seperately now)
- Add conflicts to ease upgrade from 2006.0

* Wed Jul 19 2006 Gtz Waschk <waschk@mandriva.org> 0.62-5mdv2007.0
- remove some useless static libs
- fix postun script of the sharp package

* Thu Jun 22 2006 Gtz Waschk <waschk@mandriva.org> 0.62-4mdv2007.0
- don't depend on kdelibs

* Thu Jun 15 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-3mdv2007.0
- Regenerate patch0 and merge patch1 in it
- add strict rules for lib major in file list
- fix localstatedir location (Mdv bug #23107)

* Wed Jun 14 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-2mdv2007.0
- Rebuild with correct major for qt

* Tue Jun 13 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-1mdv2007.0
- Release 0.62
- Remove patch2 (merged upstream)

* Wed May 10 2006 Gtz Waschk <waschk@mandriva.org> 0.61-5mdk
- fix dbus-sharp pkgconfig file for x86_64

* Fri May 05 2006 Gtz Waschk <waschk@mandriva.org> 0.61-4mdk
- fix x86_64 build

* Tue Apr 25 2006 Gtz Waschk <waschk@mandriva.org> 0.61-3mdk
- fix postun of the sharp package

* Sat Apr 22 2006 Gtz Waschk <waschk@mandriva.org> 0.61-2mdk
- merge sharp bindings

* Tue Feb 28 2006 Frederic Crozat <fcrozat@mandriva.com> 0.61-1mdk
- Release 0.61
- Remove patch2, no longer needed
- Patch2: allow to disable QT4 binding

* Thu Jan 26 2006 Michael Scherer <misc@mandriva.org> 0.60-2mdk
- fix missing Requires on python binding ( thanks Christiaan Welvaart )

* Wed Jan 25 2006 Frederic Crozat <fcrozat@mandriva.com> 0.60-1mdk
- Release 0.60
- Regenerate patch2
- Remove patch3 (merged upstream)

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 0.50-7mdk
- convert parallel init to LSB

* Fri Jan 06 2006 Oden Eriksson <oeriksson@mandriva.com> 0.50-6mdk
- drop selinux support

* Thu Jan 05 2006 Frederic Crozat <fcrozat@mandriva.com> 0.50-5mdk
- use mkrel
- fix buildrequires

* Mon Jan 02 2006 Olivier Blin <oblin@mandriva.com> 0.50-4mdk
- Patch1: parallel init support

* Tue Dec 27 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.50-3mdk
- patch3: use $(LIBTOOL) in Makefile.am
- fix URL

* Mon Nov 07 2005 Frederic Crozat <fcrozat@mandriva.com> 0.50-2mdk
- Enforce sub package dependency (found by till)

* Wed Oct 26 2005 Frederic Crozat <fcrozat@mandriva.com> 0.50-1mdk
- Release 0.50
- Remove patches 3, 5 (merged upstream)

* Tue Sep 13 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-5mdk
- move qt headers to the right package
- replace prereq

* Fri Sep 02 2005 Götz Waschk <waschk@mandriva.org> 0.23.4-4mdk
- rebuild to remove glitz dep

* Thu Aug 18 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.23.4-3mdk
- enable possibility to build without qt/kde stuff

* Sat Apr 30 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-2mdk
- add provides to the libdbus-glib package

* Sat Apr 23 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-1mdk
- drop patch 6
- New release 0.23.4

* Tue Mar 01 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.2-2mdk 
- Patch6 (CVS): fix python binding

* Wed Feb 23 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.2-1mdk 
- Release 0.23.2
- Remove patch4 (merged upstream)

* Wed Feb 16 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.1-1mdk 
- Release 0.23.1
- Patch5 (CVS): fix crash when setting group policy

* Wed Feb 16 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23-5mdk 
- Move dbus xinit launcher in dbus-x11 package (Mdk bug #13075)

* Wed Feb 09 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.23-4mdk
- let devel symlinks stay in standard libdir

* Tue Feb 08 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23-3mdk 
- Patch3 (Fedora): allow uid/gid to identify user/group
- Patch4 (Fedora): restrict connection to user session bus to owner or root

* Fri Jan 21 2005 Gtz Waschk <waschk@linux-mandrake.com> 0.23-2mdk
- add missing directory

* Thu Jan 20 2005 Gtz Waschk <waschk@linux-mandrake.com> 0.23-1mdk
- drop patches 1,3
- update source URL
- New release 0.23

* Wed Dec 08 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.22-7mdk 
- automatically start dbus when starting a X11 session

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.22-6mdk
- Rebuild for new python

* Mon Nov 15 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.22-5mdk
- add BuildRequires: kdelibs-devel

* Fri Nov 12 2004 Gtz Waschk <waschk@linux-mandrake.com> 0.22-4mdk
- create Qt development package

* Fri Oct 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.22-3mdk
- explicitly disable Mono bindings

* Fri Oct 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.22-2mdk
- fix detection of moc path
- merge in RH in64 fix for python bindings

* Sat Aug 14 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.22-1mdk
- Release 0.22
- Remove patch1 (merged upstream)
- enable libtoolize 
- Patch1 (Fedora): add console policy

* Tue Aug 10 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.21-4mdk
- Update patch 20 to change start order (should fix bluetooth daemon start)

* Thu Jun 17 2004 Stew Benedict <sbenedict@mandrakesoft.com> 0.21-3mdk
- add docs to -devel, dbus-monitor fixes from cvs (patch1)

* Sat Jun 05 2004 Laurent Montel <lmontel@mandrakesoft.com> 0.21-2mdk
- Rebuild

* Tue Apr 20 2004 Gtz Waschk <waschk@linux-mandrake.com> 0.21-1mdk
- fix qt build
- drop merged patch 1
- fix URL
- new version

